# `light-curve-python`

`light-curve-python` had been a previous name of [`light curve extraction package`](https://github.com/hombit/light-curve), which was renamed to `light-curve`.
Now this is an empty package which depends on `light-curve` only.
